==> node-v8.2.1.tar.xz: node-v8.2.1/deps/chakrashim/core/lib/Runtime/Base/ThreadConfigFlagsList.h <==
//-------------------------------------------------------------------------------------------------------
// Copyright (C) Microsoft. All rights reserved.
// Licensed under the MIT license. See LICENSE.txt file in the project root for full license information.
//-------------------------------------------------------------------------------------------------------

// Format: FLAG*(ThreadFlag, GlobalFlag)
FLAG(IsCollectGarbageEnabled, CollectGarbage)
FLAG(IsErrorStackTraceEnabled, errorStackTrace)
FLAG(IsES6UnicodeVerboseEnabled, ES6UnicodeVerbose)
FLAG_RELEASE(IsIntlEnabled, Intl)
FLAG_RELEASE(IsES6SpeciesEnabled, ES6Species)
FLAG_RELEASE(IsES6ClassAndExtendsEnabled, ES6Classes)
FLAG_RELEASE(IsES6DateParseFixEnabled, ES6DateParseFix)
FLAG_RELEASE(IsES6DefaultArgsEnabled, ES6DefaultArgs)
FLAG_RELEASE(IsES6DestructuringEnabled, ES6Destructuring)
FLAG_RELEASE(IsES6ForLoopSemanticsEnabled, ES6ForLoopSemantics)
FLAG_RELEASE(IsES6FunctionNameEnabled, ES6FunctionName)
FLAG_RELEASE(IsES6FunctionNameFullEnabled, ES6FunctionNameFull)
FLAG_RELEASE(IsES6GeneratorsEnabled, ES6Generators)
FLAG_RELEASE(IsES7ExponentiationOperatorEnabled, ES7ExponentiationOperator)
FLAG_RELEASE(IsES7TrailingCommaEnabled, ES7TrailingComma)
FLAG_RELEASE(IsES7ValuesEntriesEnabled, ES7ValuesEntries)
FLAG_RELEASE(IsES6IsConcatSpreadableEnabled, ES6IsConcatSpreadable)
FLAG_RELEASE(IsES6MathExtensionsEnabled, ES6Math)
FLAG_RELEASE(IsES6ModuleEnabled, ES6Module)
FLAG_RELEASE(IsES6ObjectExtensionsEnabled, ES6Object)
FLAG_RELEASE(IsES6NumberExtensionsEnabled, ES6Number)
FLAG_RELEASE(IsES6ObjectLiteralsEnabled, ES6ObjectLiterals)
FLAG_RELEASE(IsES6PromiseEnabled, ES6Promise)
FLAG_RELEASE(IsES6ProxyEnabled, ES6Proxy)
FLAG_RELEASE(IsES6RestEnabled, ES6Rest)
FLAG_RELEASE(IsES6SpreadEnabled, ES6Spread)
FLAG_RELEASE(IsES6StringExtensionsEnabled, ES6String)
FLAG_RELEASE(IsES6StringPrototypeFixEnabled, ES6StringPrototypeFixes)
FLAG_RELEASE(IsES6PrototypeChain, ES6PrototypeChain)
FLAG_RELEASE(IsES6ToPrimitiveEnabled, ES6ToPrimitive)
FLAG_RELEASE(IsES6ToLengthEnabled, ES6ToLength)
FLAG_RELEASE(IsES6ToStringTagEnabled, ES6ToStringTag)
FLAG_RELEASE(IsES6UnicodeExtensionsEnabled, ES6Unicode)
FLAG_RELEASE(IsES6UnscopablesEnabled, ES6Unscopables)
FLAG_RELEASE(IsES6RegExStickyEnabled, ES6RegExSticky)
FLAG_RELEASE(IsES6RegExPrototypePropertiesEnabled, ES6RegExPrototypeProperties)
FLAG_RELEASE(IsES6RegExSymbolsEnabled, ES6RegExSymbols)
FLAG_RELEASE(IsES6HasInstanceEnabled, ES6HasInstance)
FLAG_RELEASE(SkipSplitOnNoResult, SkipSplitOnNoResult)
FLAG_RELEASE(IsES7AsyncAndAwaitEnabled, ES7AsyncAwait)
FLAG_RELEASE(IsArrayBufferTransferEnabled, ArrayBufferTransfer)
FLAG_RELEASE(IsESObjectGetOwnPropertyDescriptorsEnabled, ESObjectGetOwnPropertyDescriptors)
FLAG_RELEASE(IsESSharedArrayBufferEnabled, ESSharedArrayBuffer)
#ifdef ENABLE_PROJECTION
FLAG(AreWinRTDelegatesInterfaces, WinRTDelegateInterfaces)
FLAG_RELEASE(IsWinRTAdaptiveAppsEnabled, WinRTAdaptiveApps)
#endif

#ifdef ENABLE_SIMDJS
//SIMD_JS
FLAG_RELEASE(IsSimdjsEnabled, Simdjs)
#endif

==> node-v8.10.0.tar.xz: node-v8.10.0/deps/chakrashim/core/lib/Runtime/Base/ThreadConfigFlagsList.h <==
//-------------------------------------------------------------------------------------------------------
// Copyright (C) Microsoft. All rights reserved.
// Licensed under the MIT license. See LICENSE.txt file in the project root for full license information.
//-------------------------------------------------------------------------------------------------------

// Format: FLAG*(ThreadFlag, GlobalFlag)
FLAG(IsCollectGarbageEnabled, CollectGarbage)
FLAG(IsErrorStackTraceEnabled, errorStackTrace)
FLAG(IsES6UnicodeVerboseEnabled, ES6UnicodeVerbose)
FLAG_RELEASE(IsIntlEnabled, Intl)
FLAG_RELEASE(IsES6SpeciesEnabled, ES6Species)
FLAG_RELEASE(IsES6ClassAndExtendsEnabled, ES6Classes)
FLAG_RELEASE(IsES6DateParseFixEnabled, ES6DateParseFix)
FLAG_RELEASE(IsES6DefaultArgsEnabled, ES6DefaultArgs)
FLAG_RELEASE(IsES6DestructuringEnabled, ES6Destructuring)
FLAG_RELEASE(IsES6ForLoopSemanticsEnabled, ES6ForLoopSemantics)
FLAG_RELEASE(IsES6FunctionNameEnabled, ES6FunctionName)
FLAG_RELEASE(IsES6FunctionNameFullEnabled, ES6FunctionNameFull)
FLAG_RELEASE(IsES6GeneratorsEnabled, ES6Generators)
FLAG_RELEASE(IsES7ExponentiationOperatorEnabled, ES7ExponentiationOperator)
FLAG_RELEASE(IsES7TrailingCommaEnabled, ES7TrailingComma)
FLAG_RELEASE(IsES7ValuesEntriesEnabled, ES7ValuesEntries)
FLAG_RELEASE(IsES6IsConcatSpreadableEnabled, ES6IsConcatSpreadable)
FLAG_RELEASE(IsES6MathExtensionsEnabled, ES6Math)
FLAG_RELEASE(IsES6ModuleEnabled, ES6Module)
FLAG_RELEASE(IsES6ObjectExtensionsEnabled, ES6Object)
FLAG_RELEASE(IsES6NumberExtensionsEnabled, ES6Number)
FLAG_RELEASE(IsES6ObjectLiteralsEnabled, ES6ObjectLiterals)
FLAG_RELEASE(IsES6PromiseEnabled, ES6Promise)
FLAG_RELEASE(IsES6ProxyEnabled, ES6Proxy)
FLAG_RELEASE(IsES6RestEnabled, ES6Rest)
FLAG_RELEASE(IsES6SpreadEnabled, ES6Spread)
FLAG_RELEASE(IsES6StringExtensionsEnabled, ES6String)
FLAG_RELEASE(IsES6StringPrototypeFixEnabled, ES6StringPrototypeFixes)
FLAG_RELEASE(IsES6PrototypeChain, ES6PrototypeChain)
FLAG_RELEASE(IsES6ToPrimitiveEnabled, ES6ToPrimitive)
FLAG_RELEASE(IsES6ToLengthEnabled, ES6ToLength)
FLAG_RELEASE(IsES6ToStringTagEnabled, ES6ToStringTag)
FLAG_RELEASE(IsES6UnicodeExtensionsEnabled, ES6Unicode)
FLAG_RELEASE(IsES6UnscopablesEnabled, ES6Unscopables)
FLAG_RELEASE(IsES6RegExStickyEnabled, ES6RegExSticky)
FLAG_RELEASE(IsES6RegExPrototypePropertiesEnabled, ES6RegExPrototypeProperties)
FLAG_RELEASE(IsES6RegExSymbolsEnabled, ES6RegExSymbols)
FLAG_RELEASE(IsES6HasInstanceEnabled, ES6HasInstance)
FLAG_RELEASE(SkipSplitOnNoResult, SkipSplitOnNoResult)
FLAG_RELEASE(IsES7AsyncAndAwaitEnabled, ES7AsyncAwait)
FLAG_RELEASE(IsESObjectGetOwnPropertyDescriptorsEnabled, ESObjectGetOwnPropertyDescriptors)
FLAG_RELEASE(IsESSharedArrayBufferEnabled, ESSharedArrayBuffer)
FLAG_RELEASE(IsESDynamicImportEnabled, ESDynamicImport)
#ifdef ENABLE_PROJECTION
FLAG(AreWinRTDelegatesInterfaces, WinRTDelegateInterfaces)
FLAG_RELEASE(IsWinRTAdaptiveAppsEnabled, WinRTAdaptiveApps)
#endif

#ifdef ENABLE_SIMDJS
//SIMD_JS
FLAG_RELEASE(IsSimdjsEnabled, Simdjs)
#endif
